@@ -27,7 +27,7 @@
 #define SHRINK_STRINGIFY(x)	#x
 #define SHRINK_STR(x)		SHRINK_STRINGIFY(x)
 #define SHRINK_VERSION_MAJOR	0
-#define SHRINK_VERSION_MINOR	3
+#define SHRINK_VERSION_MINOR	5
 #define SHRINK_VERSION_PATCH	0
 #define SHRINK_VERSION		SHRINK_STR(SHRINK_VERSION_MAJOR) "." \
 				SHRINK_STR(SHRINK_VERSION_MINOR) "." \
@@ -52,15 +52,27 @@ void		 shrink_version(int *major, int *minor, int *patch);
 #define SHRINK_L_MID		(2)
 #define SHRINK_L_MAX		(3)
 
-/* XXX do we want to expose the internal API? */
+struct shrink_ctx;
+struct shrink_ctx	*shrink_init(int, int);
+void			 shrink_cleanup(struct shrink_ctx *);
+int			 shrink_compress(struct shrink_ctx *, uint8_t *,
+			     uint8_t *, size_t, size_t *, struct timeval *);
+int			 shrink_decompress(struct shrink_ctx *, uint8_t *,
+			     uint8_t *, size_t, size_t *, struct timeval *);
+void			*shrink_malloc(struct shrink_ctx *, size_t *);
+size_t			 shrink_compress_bounds(struct shrink_ctx *, size_t);
+const char		*shrink_get_algorithm(struct shrink_ctx *);
 
-/* pretty api */
-extern int		(*s_compress)(uint8_t *, uint8_t *, size_t, size_t *,
-			    struct timeval *);
-extern int		(*s_decompress)(uint8_t *, uint8_t *, size_t,
-			    size_t *, struct timeval *);
-extern void		*(*s_malloc)(size_t *);
-extern size_t		(*s_compress_bounds)(size_t);
-extern char		*s_algorithm;
+/*
+ * old api for compatibility. DO NOT USE IN NEW CODE!
+ * To be removed completely after the end of 2012.
+ */
+int			 s_init(int algorithm, int level);
+int			 s_compress(uint8_t *, uint8_t *, size_t, size_t *,
+			     struct timeval *);
+int			 s_decompress(uint8_t *, uint8_t *, size_t, size_t *,
+			     struct timeval *);
+void			*s_malloc(size_t *);
+size_t			 s_compress_bounds(size_t);
+const char		*s_get_algorithm(void);
 
-int			s_init(int algorithm, int level);
